Estimate pitch using Praat's raw autocorrelation function
praat_pitchRawAC(
sound,
output = "ssff",
timeStep = NULL,
floor = 75,
ceiling = 600,
maxNoCandidates = 15,
gaussianWindow = FALSE,
silenceThreshold = 0.03,
voicingThreshold = 0.45,
octaveCost = 0.01,
octaveJumpCost = 0.35,
voicedUnvoicedCost = 0.14
)List in the SSFF format or data frame with estimated pitch.
String giving the file name of a sound file with the .wav extension.
String giving the output format. Should be either ssff
for the SSFF-style format used by wrassp (default) or df to output a
data frame.
Measurement interval in seconds.
Default is NULL, in which case the measurement interval is equal to
0.75 / pitch_floor.
Frequency in Hz; no pitch candidates considered below
this frequency. Default is 75.
Frequency in Hz; no pitch candidates considered above
this frequency. Default is 600.
Integer giving the maximum number of pitch candidates
to estimate. Default is 15.
Logical; should Gaussian windows be used for
estimating pitch? Default is FALSE, in which case Hanning windows are used.
Numeric giving the silence threshold when estimating
pitch in terms of amplitude relative to the global maximum. Default is
0.01.
Numeric giving the voicing threshold when estimating
pitch in terms of fractional strength in the autocorrelation function.
Default is 0.14.
Numeric specifying how much high frequency pitch candidates
should be favored in terms of fractional strength in the autocorrelation
function. Default is 0.01.
Numeric specifying how much pitch changes should be
disfavored in terms of fractional strength in the autocorrelation function.
Default is 0.35.
Numeric specifying how much transitions in voicing
value should be disfavored in terms of fractional strength in the
autocorelation function. Default is 0.14.